<?php
namespace Ak\Mailchimp\Hydrator\Entity;

use Ak\Hydrator\CompositeHydrator;
use Ak\Hydrator\Strategy\HydratorStrategy;
use Ak\Mailchimp\Entity\MailingList\CampaignDefaults;
use Ak\Mailchimp\Entity\MailingList\Contact;
use Ak\Mailchimp\Entity\MailingList\Stats;
use DateTime;
use Laminas\Hydrator\ClassMethods;
use Laminas\Hydrator\ClassMethodsHydrator;
use Laminas\Hydrator\Reflection;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\Hydrator\Strategy\DateTimeFormatterStrategy;

/**
 * Hidrira mailing liste.
 *
 * @package Ak\Mailchimp\Hydrator\Entity
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class MailingListHydrator extends CompositeHydrator
{
    /**
     * Konstruktor.
     */
    public function __construct()
    {
        parent::__construct(new ReflectionHydrator(), new ClassMethodsHydrator());

        $this->addStrategy('contact', new HydratorStrategy(new ClassMethodsHydrator(), Contact::class));
        $this->addStrategy('campaign_defaults', new HydratorStrategy(new ClassMethodsHydrator(), CampaignDefaults::class));
        $this->addStrategy('date_created', new DateTimeFormatterStrategy(DateTime::ISO8601));
        $this->addStrategy('stats', new HydratorStrategy(new MailingList\StatsHydrator(), Stats::class));
    }
}
